%define _disable_ld_no_undefined 1

%define major   1
%define libname %mklibname lttng-ust %major
%define devname %mklibname lttng-ust -d

%define ctl_major   5
%define libname_ctl %mklibname lttng-ust-ctl %ctl_major

Name:           lttng-ust
Version:        2.13.7
Release:        %mkrel 1
License:        LGPLv2 and GPLv2 and MIT
Group:          Development/C
Summary:        LTTng Userspace Tracer library
URL:            https://lttng.org/
Source0:        https://lttng.org/files/lttng-ust/%{name}-%{version}.tar.bz2
Patch0:         lttng-gen-tp-shebang.patch

BuildRequires:  texinfo
BuildRequires:  libtool
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  systemtap-sdt-devel
BuildRequires:  pkgconfig(liburcu) >= 0.12.0
BuildRequires:  pkgconfig(uuid)
# Numactl is not available on armhf
%ifnarch %{arm}
BuildRequires:  pkgconfig(numa)
%endif

%description
This library may be used by user space applications to generate
tracepoints using LTTng.

%package -n %{libname}
Summary:        LTTng Userspace Tracer library
Group:          Development/C

%description -n %{libname}
This library provides support for developing programs using
LTTng userspace tracing.

%package -n %{libname_ctl}
Summary:        LTTng Userspace CTL Tracer library
Group:          Development/C

%description -n %{libname_ctl}
This library provides support for developing programs using
LTTng userspace CTL tracing.

%package -n %{devname}
Summary:        LTTng Userspace Tracer library headers and development files
Group:          Development/C
Provides:       lttng-ust-devel = %{version}-%{release}
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Requires:       %{libname_ctl}%{?_isa} = %{version}-%{release}
Requires:       userspace-rcu-devel
Requires:       systemtap-sdt-devel

%description -n %{devname}
This library provides support for developing programs using
LTTng userspace tracing.

%package -n python3-lttngust
Summary:        Python 3 bindings for LTTng UST
Group:          Development/Python
BuildArch:      noarch
BuildRequires:  pkgconfig(python3)
%{?python_provide:%python_provide python3-lttngust}

%description -n python3-lttngust
The python3-lttngust package contains libraries needed to instrument
applications that use %{name}'s Python logging backend.

%prep
%autosetup -p1

sed -i -e '/SUBDIRS/s:examples::' doc/Makefile.am

%build
#Reinitialize libtool with the fedora version to remove Rpath
autoreconf -vif

%ifarch %{arm}
export CPPFLAGS="-DUATOMIC_NO_LINK_ERROR -DSTAP_SDT_ARG_CONSTRAINT=g"
%endif

%configure \
%ifarch %{arm}
        --disable-numa \
%endif
        --docdir=%{_docdir}/%{name} \
        --disable-static \
        --enable-python-agent \
        --with-sdt

%make_build

%install
%make_install

# we don't want these
find %{buildroot} -name '*.la' -delete

%files
%{_mandir}/man3/do_tracepoint.3.*
%{_mandir}/man3/lttng-ust.3.*
%{_mandir}/man3/lttng-ust-cyg-profile.3.*
%{_mandir}/man3/lttng-ust-dl.3.*
%{_mandir}/man3/lttng_ust_do_tracepoint.3.*
%{_mandir}/man3/lttng_ust_tracef.3.*
%{_mandir}/man3/lttng_ust_tracelog.3.*
%{_mandir}/man3/lttng_ust_tracepoint.3.*
%{_mandir}/man3/lttng_ust_tracepoint_enabled.3.*
%{_mandir}/man3/lttng_ust_vtracef.3.*
%{_mandir}/man3/lttng_ust_vtracelog.3.*
%{_mandir}/man3/tracef.3.*
%{_mandir}/man3/tracelog.3.*
%{_mandir}/man3/tracepoint.3.*
%{_mandir}/man3/tracepoint_enabled.3.*
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/ChangeLog
%{_docdir}/%{name}/java-agent.txt
%{_docdir}/%{name}/LICENSE
%{_docdir}/%{name}/README.md

%files -n %libname
%{_libdir}/*.so.%{major}{,.*}

%files -n %libname_ctl
%{_libdir}/*.so.%{ctl_major}{,.*}

%files -n %devname
%{_bindir}/lttng-gen-tp
%{_mandir}/man1/lttng-gen-tp.1.*
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/lttng-ust*.pc

%files -n python3-lttngust
%{python3_sitelib}/lttngust/
%{python3_sitelib}/lttngust-*.egg-info


%changelog
* Wed Mar 06 2024 daviddavid <daviddavid> 2.13.7-1.mga10
+ Revision: 2047806
- new version: 2.13.7

* Wed Mar 30 2022 umeabot <umeabot> 2.12.0-7.mga9
+ Revision: 1833913
- Mageia 9 Mass Rebuild

* Thu Mar 03 2022 pterjan <pterjan> 2.12.0-6.mga9
+ Revision: 1788119
- Try again to fix build on armv7hl

* Thu Mar 03 2022 pterjan <pterjan> 2.12.0-5.mga9
+ Revision: 1788097
- Try to fix build on armv7hl

* Tue Mar 01 2022 mrambo3501 <mrambo3501> 2.12.0-4.mga9
+ Revision: 1787070
- rebuild for python-3.10

* Wed Dec 01 2021 wally <wally> 2.12.0-3.mga9
+ Revision: 1760449
- rebuild for userspace-rcu 0.13.0

* Sat Jun 26 2021 wally <wally> 2.12.0-2.mga9
+ Revision: 1732545
- Rebuild for python 3.9

* Wed Apr 15 2020 daviddavid <daviddavid> 2.12.0-1.mga8
+ Revision: 1567440
- new version: 2.12.0
- rebuild for new userspace-rcu 0.12.0

* Sun Feb 16 2020 umeabot <umeabot> 2.10.4-3.mga8
+ Revision: 1532198
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Sep 16 2019 tv <tv> 2.10.4-2.mga8
+ Revision: 1442071
- rebuild for python-3.8

* Wed Aug 21 2019 daviddavid <daviddavid> 2.10.4-1.mga8
+ Revision: 1430958
- new version: 2.10.4
- add patch to build on glibc >= 2.30
- add python3-lttngust sub-package

* Sun Sep 23 2018 umeabot <umeabot> 2.6.2-3.mga7
+ Revision: 1299365
- Mageia 7 Mass Rebuild

* Tue Feb 27 2018 daviddavid <daviddavid> 2.6.2-2.mga7
+ Revision: 1205461
- rebuild for new  userspace-rcu 0.10.1

* Sat Apr 16 2016 tv <tv> 2.6.2-1.mga6
+ Revision: 1002927
- imported package lttng-ust


* Sat Apr 16 2016 Thierry Vignaud <tv@mageia.org> 2.6.2-1.mga6
- import from FC

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.6.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Aug 6 2015 Suchakra Sharma <suchakra@fedoraproject.org> - 2.6.2-2
- Remove remaining BR for SystemTap SDT and add python as a BR

* Thu Jul 23 2015 Michael Jeanson <mjeanson@gmail.com> - 2.6.2-1
- New upstream release
- Drop SystemTap SDT support
- Remove patches applied upstream

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.5.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Dec  9 2014 Peter Robinson <pbrobinson@fedoraproject.org> 2.5.1-2
- Add patch to fix aarch64 support

* Mon Nov 03 2014 Suchakra Sharma <suchakra@fedoraproject.org> - 2.5.1-1
- New upstream release
- Update URL

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue May 20 2014 Yannick Brosseau <yannick.brosseau@gmail.com> - 2.4.1-1
- New upstream bugfix release

* Sat Mar 1 2014 Suchakra Sharma <suchakra@fedoraproject.org> - 2.4.0-1
- New upstream release
- Add new files (man and doc)

* Sat Feb 22 2014 Yannick Brosseau <yannick.brosseau@gmail.com> - 2.3.0-2
- Rebuilt for URCU Soname change

* Fri Sep 20 2013 Yannick Brosseau <yannick.brosseau@gmail.com> - 2.3.0-1
- New upstream release (include snapshop feature)

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Jul 16 2013 Yannick Brosseau <yannick.brosseau@gmail.com> - 2.2.1-1
- New upstream release
- Bump URCU dependency

* Thu May 23 2013 Dan Horák <dan[at]danny.cz> - 2.1.2-2
- add build workaround for s390(x)

* Fri May 17 2013 Yannick Brosseau <yannick.brosseau@gmail.com> - 2.1.2-1
- New upstream bugfix release
- Remove patches applied upstream

* Wed Feb 27 2013 Yannick Brosseau <yannick.brosseau@gmail.com> - 2.1.1-2
- Remove dependency of probes on urcu-bp

* Tue Feb 26 2013 Yannick Brosseau <yannick.brosseau@gmail.com> - 2.1.1-1
- New upstream release

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Tue Oct 23 2012 Yannick Brosseau <yannick.brosseau@gmail.com> - 2.0.5-1
- New upstream release

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jun 22 2012 Yannick Brosseau <yannick.brosseau@gmail.com> - 2.0.4-2
- Add dependency on systemtap-sdt-devel for devel package

* Tue Jun 19 2012 Yannick Brosseau <yannick.brosseau@gmail.com> - 2.0.4-1
- New upstream release
- Updates from review comments

* Thu Jun 14 2012 Yannick Brosseau <yannick.brosseau@gmail.com> - 2.0.3-1
- New package, inspired by the one from OpenSuse

